SpanSelector
~~~~~~~~~~~~
``span_stays`` is deprecated, use ``interactive`` argument instead
Several `~matplotlib.widgets.SpanSelector` class internals have been privatized 
and deprecated:
- ``pressv``
- ``prev``
- ``rect``
- ``rectprops``
- ``active_handle``
- ``span_stays``


Several `~matplotlib.widgets.RectangleSelector` and
`~matplotlib.widgets.EllipseSelector` class internals have been privatized and
deprecated:
- ``to_draw``
- ``drawtype``
- ``rectprops``
- ``active_handle``
- ``interactive``
